ActionInfo class

Represents information about the actions to be executed when a rule is activated.

The ActionInfo object has the following properties:

  • onSuccess: The action to be executed when the rule is activated successfully.
  • onFailure: The action to be executed when the rule is not activated successfully.

The onSuccess and onFailure properties are defined using an ActionDefinition object.

Constructors

ActionInfo({ActionDefinition? onSuccess, ActionDefinition? onFailure})

Properties

hashCode → int
The hash code for this object.
no setterinherited
onFailure → ActionDefinition?
The action to be executed when the rule execution fails due to an error.
final
onSuccess → ActionDefinition?
The action to be executed when the rule is activated successfully.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the ActionInfo object to a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ActionInfo
Creates an ActionInfo object from a JSON object.